@@ -25,8 +25,6 @@ def parse_query(query, sql_dialect, feature_name=None) -> tuple:
     standardized_query, variables = wrap_variables(
         query=standardized_query, encoding_character='', wrap_character=ENCODING_CHARACTER,
     )
-    print('encapsulated')
-    print(standardized_query)
     query_ast = dialect.parse_query(query=standardized_query)
     query_input = label_input(variable_set=variables, query_ast=query_ast)
 
